@@ -1,7 +1,10 @@
 /* -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2025, Lawrence Livermore National Security
+ * Copyright (c) 2025, Lawrence Livermore National Security,
+ * University of Maryland Baltimore County, and the SUNDIALS contributors.
+ * Copyright (c) 2013-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
+ * Copyright (c) 2002-2013, Lawrence Livermore National Security.
  * All rights reserved.
  *
  * See the top-level LICENSE and NOTICE files for details.
@@ -20,13 +23,12 @@
 #ifndef _SUNDIALS_ERRORS_IMPL_H
 #define _SUNDIALS_ERRORS_IMPL_H
 
+#include <sundials/sundials_config.h>
+#include <sundials/sundials_context.h>
 #include <sundials/sundials_errors.h>
-
-#include "sundials/sundials_config.h"
-#include "sundials/sundials_context.h"
-#include "sundials/sundials_export.h"
-#include "sundials/sundials_logger.h"
-#include "sundials/sundials_types.h"
+#include <sundials/sundials_export.h>
+#include <sundials/sundials_logger.h>
+#include <sundials/sundials_types.h>
 
 #ifdef __cplusplus /* wrapper to enable C++ usage */
 extern "C" {
